#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pqueue
version:              1.6.0.0
visibility:           public
id:                   pqueue-1.6.0.0-1FmOIQL2HTdFHe9DXk1SV2
key:                  pqueue-1.6.0.0-1FmOIQL2HTdFHe9DXk1SV2
license:              BSD-3-Clause
maintainer:
    Lennart Spitzner <hexagoxel@hexagoxel.de>,
    Louis Wasserman <wasserman.louis@gmail.com>,
    konsumlamm <konsumlamm@gmail.com>,
    David Feuer <David.Feuer@gmail.com>

author:               Louis Wasserman
stability:            experimental
homepage:             https://github.com/lspitzner/pqueue
synopsis:             Reliable, persistent, fast priority queues.
description:
    A fast, reliable priority queue implementation based on a binomial heap.

category:             Data Structures
abi:                  f312828c08b8446a415f516fa76de32d
exposed:              True
exposed-modules:
    Data.PQueue.Max Data.PQueue.Min Data.PQueue.Prio.Max
    Data.PQueue.Prio.Min

hidden-modules:
    Data.PQueue.Prio.Internals Data.PQueue.Internals
    BinomialQueue.Internals BinomialQueue.Min BinomialQueue.Max
    Data.PQueue.Internals.Classes Data.PQueue.Internals.Down
    Data.PQueue.Prio.Max.Internals Nattish

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pqueue-1.6.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pqueue-1.6.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pqueue-1.6.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pqueue
hs-libraries:         HSpqueue-1.6.0.0-1FmOIQL2HTdFHe9DXk1SV2
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr

haddock-interfaces:   /usr/share/doc/haskell-pqueue/html/pqueue.haddock
haddock-html:         /usr/share/doc/haskell-pqueue/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

